]> git.draconx.ca Git - rrace.git/commitdiff
Avoid motif headers in x11.c.
authorNick Bowler <nbowler@draconx.ca>
Thu, 10 Mar 2022 01:37:10 +0000 (20:37 -0500)
committerNick Bowler <nbowler@draconx.ca>
Thu, 10 Mar 2022 01:59:53 +0000 (20:59 -0500)
We don't actually use any of motif in this module aside from a couple
macros which alias Xt string definitions.  So let's stick with the Xt
names.

src/x11.c

index ea0fdbac90a47688a38c4787a125118b93d655c1..1bd19c97f158ae01efb79a9c8fafc08805c398a7 100644 (file)
--- a/src/x11.c
+++ b/src/x11.c
@@ -23,7 +23,7 @@
 #include <assert.h>
 
 #include <X11/Intrinsic.h>
-#include <Xm/XmStrDefs.h>
+#include <X11/StringDefs.h>
 #include <X11/Xatom.h>
 #include <X11/Shell.h>
 #include "motif.h"
@@ -171,7 +171,7 @@ void x11_redraw_goal(struct app_state *state, uint_fast32_t mask)
        Dimension w, h;
        int i;
 
-       XtVaGetValues(state->goal, XmNwidth, &w, XmNheight, &h, (char *)NULL);
+       XtVaGetValues(state->goal, XtNwidth, &w, XtNheight, &h, (char *)NULL);
        for (i = 0; i < 9; i++) {
                int x = i%3, y = i/3;
 
@@ -226,11 +226,11 @@ void x11_redraw_icon(struct app_state *state, Widget shell)
        }
 
        /*
* Clear and reset XmNiconPixmap otherwise it seems dtwm will not
         * notice the changed icon.
         */
-       XtVaSetValues(shell, XmNiconPixmap, None, (char *)NULL);
-       XtVaSetValues(shell, XmNiconPixmap, state->icon_pixmap, (char *)NULL);
+       XtVaSetValues(shell, XtNiconPixmap, None, (char *)NULL);
+       XtVaSetValues(shell, XtNiconPixmap, state->icon_pixmap, (char *)NULL);
 
        if (wm_icon) {
                Atom net_wm_icon = XInternAtom(display, "_NET_WM_ICON", FALSE);
@@ -251,7 +251,7 @@ void x11_redraw_game(struct app_state *state, uint_fast32_t mask)
        Dimension w, h;
        int i;
 
-       XtVaGetValues(state->game, XmNwidth, &w, XmNheight, &h, (char *)NULL);
+       XtVaGetValues(state->game, XtNwidth, &w, XtNheight, &h, (char *)NULL);
        w /= 5; h /= 5;
 
        for (i = 0; i < 25; i++) {
@@ -226,11 +226,11 @@ void x11_redraw_icon(struct app_state *state, Widget shell)
 
        /*
-        * Clear and reset XmNiconPixmap otherwise it seems dtwm will not
+        * Clear and reset XtNiconPixmap otherwise it seems dtwm will not
         * notice the changed icon.
         */